# Table of Contents

- [sap-signavio-advanced-configuration](<./sap-signavio-advanced-configuration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Advanced Configuration](<./Advanced-Configuration.md>)
  - [Endpoints](<./Advanced-Configuration/Endpoints.md>)
  - [Editordata Endpoint](<./Advanced-Configuration/Editordata-Endpoint.md>)
  - [Process Language Example](<./Advanced-Configuration/Process-Language-Example.md>)
  - [Model Endpoint](<./Advanced-Configuration/Model-Endpoint.md>)
  - [Glossary Endpoint](<./Advanced-Configuration/Glossary-Endpoint.md>)
  - [Advanced Tab](<./Advanced-Configuration/Advanced-Tab.md>)
  - [Case 1: A SAP Signavio Field to a Static Value](<./Advanced-Configuration/Case-1-A-SAP-Signavio-Field-to-a-Static-Value.md>)
  - [Case 2: SAP Signavio Attributes to Fields](<./Advanced-Configuration/Case-2-SAP-Signavio-Attributes-to-Fields.md>)
  - [Case 3: SAP Signavio attributes with Value Mappings](<./Advanced-Configuration/Case-3-SAP-Signavio-attributes-with-Value-Mappings.md>)
  - [Case 4: Multiple SAP Signavio Attributes Combined](<./Advanced-Configuration/Case-4-Multiple-SAP-Signavio-Attributes-Combined.md>)
  - [Case 5: Use Complex Expressions in Value Mappings](<./Advanced-Configuration/Case-5-Use-Complex-Expressions-in-Value-Mappings.md>)
  - [Case 6: Tagging Fact Sheets using SAP Signavio Attributes](<./Advanced-Configuration/Case-6-Tagging-Fact-Sheets-using-SAP-Signavio-Attributes.md>)
  - [Case 7: SAP Signavio Collaboration Hub](<./Advanced-Configuration/Case-7-SAP-Signavio-Collaboration-Hub.md>)
  - [Case 8: Mapping SAP Signavio Attributes to Subscriptions](<./Advanced-Configuration/Case-8-Mapping-SAP-Signavio-Attributes-to-Subscriptions.md>)
  - [Case 9: Mapping SAP Signavio Glossary Items to Fact Sheets](<./Advanced-Configuration/Case-9-Mapping-SAP-Signavio-Glossary-Items-to-Fact-Sheets.md>)
  - [Case 10: Ignoring linked Process Model relations based on <Custom Attributes> for Top-Down and Bottom-Up](<./Advanced-Configuration/Case-10-Ignoring-linked-Process-Model-relations-based-on-Custom-Attributes-for-Top-Down-and-Bottom-Up.md>)
  - [Case 11: maximumDeletionRatio used to protect of unwanted data loss](<./Advanced-Configuration/Case-11-maximumDeletionRatio-used-to-protect-of-unwanted-data-loss.md>)
  - [Case 12: forceWrite used to create glossary items with conflicting name](<./Advanced-Configuration/Case-12-forceWrite-used-to-create-glossary-items-with-conflicting-name.md>)
  - [Case 13: Include tasks in relations to Glossaries](<./Advanced-Configuration/Case-13-Include-tasks-in-relations-to-Glossaries.md>)
  - [Case 14: Match Glossary Items Based on displayName](<./Advanced-Configuration/Case-14-Match-Glossary-Items-Based-on-displayName.md>)
  - [Configuration Complete JSON Example](<./Advanced-Configuration/Configuration-Complete-JSON-Example.md>)
  - [Advanced Filter to the Processes coming from SAP Signavio](<./Advanced-Configuration/Advanced-Filter-to-the-Processes-coming-from-SAP-Signavio.md>)
  - [Advanced Inbound Mappings (Processes and Glossary Items)](<./Advanced-Configuration/Advanced-Inbound-Mappings-Processes-and-Glossary-Items.md>)
  - [Was this page helpful?](<./Advanced-Configuration/Was-this-page-helpful.md>)
